@@ -57,6 +57,27 @@
 #   define USING_DBG 1
 #endif
 
+#define DBUSPY_PY_VERSION_AT_LEAST(x, y, z, w) \
+    (PY_VERSION_HEX >= ((x * 0x01000000) + (y * 0x010000) + (z * 0x0100) + w))
+
+#if !DBUSPY_PY_VERSION_AT_LEAST(3, 13, 0, 0xc0)
+static inline int backport_PyWeakref_GetRef(PyObject *ref, PyObject **pobj)
+{
+    PyObject *obj = PyWeakref_GetObject(ref);
+
+    if (obj && obj != Py_None) {
+        Py_INCREF(obj);
+        *pobj = obj;
+        return 1;
+    }
+    else {
+        *pobj = NULL;
+        return 0;
+    }
+}
+#define PyWeakref_GetRef(ref, pobj) backport_PyWeakref_GetRef(ref, pobj)
+#endif
+
 #define DEFINE_CHECK(type) \
 static inline int type##_Check (PyObject *o) \
 { \
@@ -92,29 +113,7 @@ static inline int type##_CheckExact (PyObject *o) \
     (PyUnicode_Check(obj) ? (obj) : NULL), \
     (PyUnicode_Check(obj) ? NULL : PyBytes_AS_STRING(obj))
 
-#ifdef PY3
-#define NATIVEINT_TYPE (PyLong_Type)
-#define NATIVEINT_FROMLONG(x) (PyLong_FromLong(x))
-#define NATIVEINT_ASLONG(x) (PyLong_AsLong(x))
-#define INTORLONG_CHECK(obj) (PyLong_Check(obj))
-#define NATIVESTR_TYPE (PyUnicode_Type)
-#define NATIVESTR_CHECK(obj) (PyUnicode_Check(obj))
-#define NATIVESTR_FROMSTR(obj) (PyUnicode_FromString(obj))
-#else
-#define NATIVEINT_TYPE (PyInt_Type)
-#define NATIVEINT_FROMLONG(x) (PyInt_FromLong(x))
-#define NATIVEINT_ASLONG(x) (PyInt_AsLong(x))
-#define INTORLONG_CHECK(obj) (PyLong_Check(obj) || PyInt_Check(obj))
-#define NATIVESTR_TYPE (PyBytes_Type)
-#define NATIVESTR_CHECK(obj) (PyBytes_Check(obj))
-#define NATIVESTR_FROMSTR(obj) (PyBytes_FromString(obj))
-#endif
-
-#ifdef PY3
 PyMODINIT_FUNC PyInit__dbus_bindings(void);
-#else
-PyMODINIT_FUNC init_dbus_bindings(void);
-#endif
 
 /* conn.c */
 extern PyTypeObject DBusPyConnection_Type;
@@ -154,10 +153,6 @@ DEFINE_CHECK(DBusPyByteArray)
 DEFINE_CHECK(DBusPyByte)
 extern PyTypeObject DBusPyString_Type;
 DEFINE_CHECK(DBusPyString)
-#ifndef PY3
-extern PyTypeObject DBusPyUTF8String_Type;
-DEFINE_CHECK(DBusPyUTF8String)
-#endif
 extern PyTypeObject DBusPyDouble_Type;
 DEFINE_CHECK(DBusPyDouble)
 extern PyTypeObject DBusPyInt16_Type, DBusPyUInt16_Type;
